@@ -1,7 +1,7 @@
 # Miscellaneous administrivia.
 
 package Bot::Pastebot::Administrivia;
-
+$Bot::Pastebot::Administrivia::VERSION = '0.600';
 use warnings;
 use strict;
 
@@ -63,3 +63,28 @@ sub write_pidfile {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Bot::Pastebot::Administrivia - The part that helps administrators.
+
+=head1 VERSION
+
+version 0.600
+
+=head1 DESCRIPTION
+
+See L<pastebot> for the full documentation, including syntax and
+options for pastebot's configuration files.
+
+This module implements PID file management, and it might handle
+daemonization later on.
+
+=head1 BUGS
+
+Some form of this code probably exists in other CPAN modules.
+The rest should probably be distributed separately.
+
+=cut
